==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/DetrendedPriceOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { DetrendedPriceOscillatorIndicatorDescription } from "./DetrendedPriceOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let DetrendedPriceOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class DetrendedPriceOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (DetrendedPriceOscillatorIndicatorDescriptionMetadata.a == null) {
                DetrendedPriceOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DetrendedPriceOscillatorIndicatorDescriptionMetadata.c(DetrendedPriceOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(DetrendedPriceOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(DetrendedPriceOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            DetrendedPriceOscillatorIndicatorDescriptionMetadata.b(a);
            a.ad("DetrendedPriceOscillatorIndicator", () => new DetrendedPriceOscillatorIndicatorDescription());
            a.ac("DetrendedPriceOscillatorIndicator", DetrendedPriceOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    DetrendedPriceOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(DetrendedPriceOscillatorIndicatorDescriptionMetadata, 'DetrendedPriceOscillatorIndicatorDescriptionMetadata');
    DetrendedPriceOscillatorIndicatorDescriptionMetadata.a = null;
    return DetrendedPriceOscillatorIndicatorDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/DetrendedPriceOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { DetrendedPriceOscillatorIndicatorDescription } from "./DetrendedPriceOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let DetrendedPriceOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class DetrendedPriceOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (DetrendedPriceOscillatorIndicatorDescriptionMetadata.a == null) {
                DetrendedPriceOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DetrendedPriceOscillatorIndicatorDescriptionMetadata.c(DetrendedPriceOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(DetrendedPriceOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(DetrendedPriceOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            DetrendedPriceOscillatorIndicatorDescriptionMetadata.b(a);
            a.ae("DetrendedPriceOscillatorIndicator", () => new DetrendedPriceOscillatorIndicatorDescription());
            a.ad("DetrendedPriceOscillatorIndicator", DetrendedPriceOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    DetrendedPriceOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(DetrendedPriceOscillatorIndicatorDescriptionMetadata, 'DetrendedPriceOscillatorIndicatorDescriptionMetadata');
    DetrendedPriceOscillatorIndicatorDescriptionMetadata.a = null;
    return DetrendedPriceOscillatorIndicatorDescriptionMetadata;
})();
